<?php
/**
 * MyBB 1.8
 * Copyright 2014 MyBB Group, All Rights Reserved
 *
 * Website: http://www.mybb.com
 * License: http://www.mybb.com/about/license
 *
 */

/**
 * Upgrade Script: 1.4.4
 */


$upgrade_detail = array(
	"revert_all_templates" => 0,
	"revert_all_themes" => 0,
	"revert_all_settings" => 0
);

@set_time_limit(0);

function upgrade15_dbchanges()
{
	global $db, $output, $mybb, $cache;

	$output->print_header("Exécution des requêtes");

	echo "<p>Exécution des requêtes nécessaires.</p>";
	flush();

	if($db->type != "pgsql")
	{
		$db->update_query("settinggroups", array('isdefault' => '1'), "isdefault='yes'");
		$db->update_query("settinggroups", array('isdefault' => '0'), "isdefault='no'");

		$db->write_query("ALTER TABLE ".TABLE_PREFIX."events CHANGE timezone timezone varchar(4) NOT NULL default '0'");
	}

	if($db->type == "pgsql")
	{
		$db->write_query("ALTER TABLE ".TABLE_PREFIX."warnings ALTER COLUMN revokereason SET default ''");
		$db->write_query("ALTER TABLE ".TABLE_PREFIX."warnings ALTER COLUMN notes SET default ''");
	}

	$cache->update("internal_settings", array('encryption_key' => random_str(32)));

	if($db->type != "sqlite")
	{
		$ip_index = $db->index_exists("sessions", "ip");

		if($ip_index == false)
		{
			if($db->type == "pgsql")
			{
				$db->write_query("CREATE INDEX ip ON ".TABLE_PREFIX."sessions (ip)");
			}
			else
			{
				$db->write_query("ALTER TABLE ".TABLE_PREFIX."sessions ADD INDEX (`ip`)");
			}
		}
	}

	$contents .= "Cliquez sur \"Suivant\" pour continuer le processus de mise à jour.</p>";
	$output->print_contents($contents);
	$output->print_footer("15_usernameverify");
}

function upgrade15_usernameverify()
{
	global $db, $output, $mybb;

	$output->print_header("Exécution des requêtes");

	echo "<p><span style=\"font-size: xx-large\">ATTENTION - LISEZ BIEN CE QUI SUIT:</span> L'étape suivante de ce processus supprimera <strong>TOUTES</strong> les virgules (,) dans les <i>noms d'utilisateurs</i> de votre forum qui en contiennent. La raison de cette modification c'est que les virgules dans les noms d'utilisateurs peuvent entraîner des erreurs d'envoi de messages privés vers ces utilisateurs.</p>";
	flush();

	$contents .= "Cliquez sur \"Suivant\" pour continuer le processus de mise à jour après avoir lu l'avertissement.</p>";
	$output->print_contents($contents);
	$output->print_footer("15_usernameupdate");
}

function upgrade15_usernameupdate()
{
	global $db, $output, $mybb, $plugins;

	$output->print_header("Exécution des requêtes");

	echo "<p>Mise à jour des noms d'utilisateurs.</p>";
	flush();

	require_once MYBB_ROOT."inc/datahandler.php";
	require_once MYBB_ROOT."inc/datahandlers/user.php";
	// Load plugin system for datahandler
	require_once MYBB_ROOT."inc/class_plugins.php";
	$plugins = new pluginSystem;

	$not_renameable = array();

	// Because commas can cause some problems with private message sending in usernames we have to remove them
	$query = $db->simple_select("users", "uid, username", "username LIKE '%,%'");
	while($user = $db->fetch_array($query))
	{
		$prefix = '';
		$userhandler = new UserDataHandler('update');

		do
		{
			$username = str_replace(',', '', $user['username']).'_'.$prefix;

			$updated_user = array(
				"uid" => $user['uid'],
				"username" => $username
			);
			$userhandler->set_data($updated_user);

			++$prefix;
		}
		while(!$userhandler->verify_username() || $userhandler->verify_username_exists());

		if(!$userhandler->validate_user())
		{
			$not_renameable[] = htmlspecialchars_uni($user['username']);
		}
		else
		{
			$db->update_query("users", array('username' => $db->escape_string($username)), "uid='{$user['uid']}'");
			$db->update_query("posts", array('username' => $db->escape_string($username)), "uid='{$user['uid']}'");
			$db->update_query("threads", array('username' => $db->escape_string($username)), "uid='{$user['uid']}'");
			$db->update_query("threads", array('lastposter' => $db->escape_string($username)), "lastposteruid='{$user['uid']}'");
			$db->update_query("forums", array('lastposter' => $db->escape_string($username)), "lastposteruid='{$user['uid']}'");

			update_stats(array("numusers" => "+0"));
		}
	}

	if(!empty($not_renameable))
	{
		echo "<span style=\"color: red;\">NOTICE:</span> Les utilisateurs suivants ne peuvent être renommés automatiquement. Renommez manuellement ces utilisateurs dans l'Admin après que le processus de mise à jour sera terminé :<br />
		<ul>
		<li>";
		echo implode('</li>\n<li>', $not_renameable);
		echo "</li>
		</ul>";
	}

	$contents .= "Cliquez sur \"Suivant\" pour continuer le processus de mise à jour.</p>";
	$output->print_contents($contents);
	$output->print_footer("15_done");
}

